pyxmpp2.settings._YesNoAction

Package pyxmpp2 :: Module settings :: Class _YesNoAction |
[hide private]

# Class _YesNoAction

Custom std:argparse option to handle boolean options via '--no-' prefixes.

For every "--something" option a "--no-something" option will be added storing a `False` value (original option will store `True`).

Instance Methods | [hide private]
__init__(self, option_strings, **kwargs) x.__init__(...) initializes x; see help(type(x)) for signature |
__call__(self, parser, namespace, value, option_string=None) |
Inherited from `argparse.Action` (private): `_get_kwargs` Inherited from `argparse._AttributeHolder`: `__repr__` Inherited from `argparse._AttributeHolder` (private): `_get_args` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, option_strings, **kwargs) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __call__(self, parser, namespace, value, option_string=None) (Call operator) |
Overrides: argparse.Action.__call__